aboutsummaryrefslogtreecommitdiffstats
path: root/epan/dissectors/packet-sigcomp.c
diff options
context:
space:
mode:
authorJörg Mayer <jmayer@loplof.de>2006-01-05 13:01:08 +0000
committerJörg Mayer <jmayer@loplof.de>2006-01-05 13:01:08 +0000
commitf9a57f08d1960cf7f6d898645d4e9f0ee384c0e7 (patch)
tree2ec913d2de0cecf04e92c11547a05cd175a5f66a /epan/dissectors/packet-sigcomp.c
parent1cd8e8ca0c6df4cedec907b1f1c2e634f3a92a91 (diff)
Bill Meier:
Spelling fixes. svn path=/trunk/; revision=16956
Diffstat (limited to 'epan/dissectors/packet-sigcomp.c')
-rw-r--r--epan/dissectors/packet-sigcomp.c18
1 files changed, 9 insertions, 9 deletions
diff --git a/epan/dissectors/packet-sigcomp.c b/epan/dissectors/packet-sigcomp.c
index ebf66dc153..9e383a11f3 100644
--- a/epan/dissectors/packet-sigcomp.c
+++ b/epan/dissectors/packet-sigcomp.c
@@ -125,14 +125,14 @@ static guint SigCompUDPPort2 = 6666;
static guint SigCompTCPPort1 = 5555;
static guint SigCompTCPPort2 = 6666;
/* Default preference wether to display the bytecode in UDVM operands or not */
static gboolean display_udvm_bytecode = FALSE;
/* Default preference wether to dissect the UDVM code or not */
static gboolean dissect_udvm_code = TRUE;
static gboolean display_raw_txt = FALSE;
/* Default preference wether to decompress the message or not */
static gboolean decompress = TRUE;
/* Default preference wether to print debug info at execution of UDVM
* 0 = No printout
* 1 = details level 1
* 2 = details level 2
@@ -2602,24 +2602,24 @@ proto_register_sigcomp(void)
&SigCompTCPPort2);
prefs_register_bool_preference(sigcomp_module, "display.udvm.code",
"Dissect the UDVM code",
- "Preference wether to Dissect the UDVM code or not",
+ "Preference whether to Dissect the UDVM code or not",
&dissect_udvm_code);
prefs_register_bool_preference(sigcomp_module, "display.bytecode",
"Display the bytecode of operands",
- "preference wether to display the bytecode in UDVM operands or not",
+ "preference whether to display the bytecode in UDVM operands or not",
&display_udvm_bytecode);
prefs_register_bool_preference(sigcomp_module, "decomp.msg",
"Decompress message",
- "preference wether to decompress message or not",
+ "preference whether to decompress message or not",
&decompress);
prefs_register_bool_preference(sigcomp_module, "display.decomp.msg.as.txt",
"Displays the decompressed message as text",
- "preference wether to display the decompressed message as raw text or not",
+ "preference whether to display the decompressed message as raw text or not",
&display_raw_txt);
prefs_register_enum_preference(sigcomp_module, "show.udvm.execution",
"Level of detail of UDVM execution",
- "0 = UDVM executes silently, then incrising detail about execution of UDVM instructions, Warning! CPU intense at high detail",
+ "0 = UDVM executes silently, then increasing detail about execution of UDVM instructions, Warning! CPU intense at high detail",
&udvm_print_detail_level, udvm_detail_vals, FALSE);
register_init_routine(&sigcomp_init_protocol);
@@ -125,14 +125,14 @@ static guint SigCompUDPPort2 = 6666;
static guint SigCompTCPPort1 = 5555;
static guint SigCompTCPPort2 = 6666;
-/* Default preference wether to display the bytecode in UDVM operands or not */
+/* Default preference whether to display the bytecode in UDVM operands or not */
static gboolean display_udvm_bytecode = FALSE;
@@ -125,14 +125,14 @@ static guint SigCompUDPPort2 = 6666;
static gboolean display_udvm_bytecode = FALSE;
-/* Default preference wether to dissect the UDVM code or not */
+/* Default preference whether to dissect the UDVM code or not */
static gboolean dissect_udvm_code = TRUE;
static gboolean display_raw_txt = FALSE;
@@ -125,14 +125,14 @@ static guint SigCompUDPPort2 = 6666;
static gboolean dissect_udvm_code = TRUE;
static gboolean display_raw_txt = FALSE;
-/* Default preference wether to decompress the message or not */
+/* Default preference whether to decompress the message or not */
static gboolean decompress = TRUE;
@@ -125,14 +125,14 @@ static guint SigCompUDPPort2 = 6666;
static gboolean decompress = TRUE;
-/* Default preference wether to print debug info at execution of UDVM
+/* Default preference whether to print debug info at execution of UDVM
* 0 = No printout
* 1 = details level 1